==> auth0-lock-11.7.2.jar: META-INF/resources/webjars/auth0-lock/11.7.2/lib/i18n/ro.js <==
'use strict';

exports.__esModule = true;
// This file was automatically translated.
// Feel free to submit a PR if you find a more accurate translation.

exports.default = {
  error: {
    forgotPassword: {
      too_many_requests: 'Ai depășit limita de introducere a parolei. Avem rugămintea să aștepți până la următoarea încercare.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de recuperare a parolei.',
      enterprise_email: 'Domeniul e-mailului dvs. face parte dintr-un furnizor de identitate de tip Enterprise. Pentru a reseta parola, consultați administratorul de securitate.'
    },
    login: {
      blocked_user: 'Utilizatorul este blocat.',
      invalid_user_password: 'Date de conectare greșite.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de conectare.',
      'lock.invalid_code': 'Cod greșit.',
      'lock.invalid_email_password': 'Email sau parolă greșite.',
      'lock.invalid_username_password': 'Nume utilizator sau parolă greșite.',
      'lock.network': 'Nu am putut să ne conectăm la server. Avem rugămintea să verifici conexiunea și să încerci din nou.',
      'lock.popup_closed': 'Fereastra popup a fost închisă. Te rugăm încearcă din nou.',
      'lock.unauthorized': 'Nu ai primit permisiunea să te conectezi. Te rugăm încearcă din nou.',
      'lock.mfa_registration_required': 'Dispozitivul tău nu permite conectarea. Avem rugămintea să verifici setările.',
      'lock.mfa_invalid_code': 'Cod greșit. Te rugăm să încerci din nou',
      password_change_required: 'Trebuie să schimbi parola de acces. Parola a expirat sau este prima oară când te conectezi.',
      password_leaked: 'Am identificat o posibilă problemă de securitate cu acest cont. Am blocat contul pentru a te proteja. Urmează să primești un email cu instrucțiunile de deblocare a contului',
      too_many_attempts: 'Contul tău a fost blocat după mai multe încercări nereușite de conectare.',
      session_missing: 'Nu am putut finaliza procesul de autentificare. Avem rugămintea să încerci după ce închizi toate ferestrele deschise.',
      'hrd.not_matching_email': 'Te rugăm să folosești adresa de email corporate pentru conectare.'
    },
    passwordless: {
      'bad.email': 'Adresa de email este invalidă',
      'bad.phone_number': 'Numărul de telefon este invalid',
      'lock.fallback': 'Ne pare rău, ceva nu a funcționat'
    },
    signUp: {
      invalid_password: 'Parolă invalidă.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de înregistrare.',
      password_dictionary_error: 'Parola este prea comună.',
      password_no_user_info_error: 'Parola este similară cu utilizatorul.',
      password_strength_error: 'Parola este prea ușoară.',
      user_exists: 'Utilizator existent.',
      username_exists: 'Nume utilizator existent.'
    }
  },
  success: {
    logIn: 'Îți mulțumim pentru înregistrare.',
    forgotPassword: 'Ți-am transmis un email pentru resetarea parolei.',
    magicLink: 'Ți-am trimis un email pentru a te înregistra<br />la %s.',
    signUp: 'Îți mulțumim pentru înregistrare.'
  },
  blankErrorHint: 'Câmpul nu poate fi gol',
  codeInputPlaceholder: 'codul tău',
  databaseEnterpriseLoginInstructions: '',
  databaseEnterpriseAlternativeLoginInstructions: 'sau',
  databaseSignUpInstructions: '',
  databaseAlternativeSignUpInstructions: 'sau',
  emailInputPlaceholder: 'yours@example.com',
  enterpriseLoginIntructions: 'Înregistrează-te cu datele corporate.',
  enterpriseActiveLoginInstructions: ' Înregistrează-te cu datele corporate la %s.',
  failedLabel: 'Eșuat!',
  forgotPasswordTitle: 'Resetează parola',
  forgotPasswordAction: 'Nu îți amintești parola?',
  forgotPasswordInstructions: 'Avem rugămintea să introduci adresa de email. Urmează să primești un email pentru resetarea parolei.',
  forgotPasswordSubmitLabel: 'Email transmis',
  invalidErrorHint: 'Invalid',
  lastLoginInstructions: 'Ultima oară când te-ai conectat',
  loginAtLabel: ' Autentifică-te cu %s',
  loginLabel: 'Autentifică-te',
  loginSubmitLabel: 'Autentifică-te',
  loginWithLabel: ' Autentifică-te cu %s',
  notYourAccountAction: 'Nu este contul tău?',
  passwordInputPlaceholder: 'parola ta',
  passwordStrength: {
    containsAtLeast: 'Include cel puțin %d din urmatoarele %d caractere:',
    identicalChars: 'Nu mai mult de %d caractere identice (e.x., "%s" nu sunt permise)',
    nonEmpty: 'Este necesară o parolă pentru logare',
    numbers: 'Numere (de la 0-9)',
    lengthAtLeast: 'Cel puțin %d caractere lungime',
    lowerCase: 'Litere mici (a-z)',
    shouldContain: 'Trebuie să conțină:',
    specialCharacters: 'Caractere speciale (e.g. !@#$%^&*)',
    upperCase: 'Litere cu majuscule (A-Z)'
  },
  passwordlessEmailAlternativeInstructions: 'Dacă nu, introdu adresa de email pentru conectare<br/>sau creează un cont.',
  passwordlessEmailCodeInstructions: 'Un email cu codul a fost trimis la %s.',
  passwordlessEmailInstructions: 'Introdu adresa de email pentru conectare<br/>sau creează un cont',
  passwordlessSMSAlternativeInstructions: ' Dacă nu, introdu un număr de telefon pentru conectare <br/>sau creează un cont',
  passwordlessSMSCodeInstructions: 'Un SMS cu codul de acces a fost trimis la<br/>la %s.',
  passwordlessSMSInstructions: 'Introdu numărul de telefon pentru conectare<br/>sau creează un cont',
  phoneNumberInputPlaceholder: 'numărul tău de telefon',
  resendCodeAction: 'Nu ai primit codul de acces? ',
  resendLabel: 'Retrimite',
  resendingLabel: 'Se retrimite...',
  retryLabel: 'Reîncearcă',
  sentLabel: 'Transmis!',
  showPassword: 'Arată parola',
  signupTitle: 'Inregistrează-te',
  signUpLabel: ' Inregistrează-te ',
  signUpSubmitLabel: ' Inregistrează-te ',
  signUpTerms: '',
  signUpWithLabel: ' Inregistrează-te cu %s',
  socialLoginInstructions: '',
  socialSignUpInstructions: '',
  ssoEnabled: ' Inregistrare activată',
  submitLabel: 'Trimite',
  unrecoverableError: 'Ceva nu a mers.<br />Avem rugămintea să contactezi serviciul de suport tehnic.',
  usernameFormatErrorHint: 'Folosește %d-%d litere, cifre și următoarele caractere speciale: "_", ".", "+", "-"',
  usernameInputPlaceholder: 'numele tău de utilizator',
  usernameOrEmailInputPlaceholder: 'utilizator/email',
  title: 'Auth0',
  welcome: 'Bine ai venit %s!',
  windowsAuthInstructions: 'Ești conectat de pe serverul tău corporate',
  windowsAuthLabel: 'Autentificare Windows ',
  mfaInputPlaceholder: 'Cod',
  mfaLoginTitle: 'Verificare în doi pași',
  mfaLoginInstructions: 'Te rugăm să introduci codul de autentificare generat de aplicația mobilă.',
  mfaSubmitLabel: 'Conectare',
  mfaCodeErrorHint: 'Utilizează %d cifre'
};

==> auth0-lock-11.14.1.jar: META-INF/resources/webjars/auth0-lock/11.14.1/lib/i18n/ro.js <==
'use strict';

exports.__esModule = true;
// This file was automatically translated.
// Feel free to submit a PR if you find a more accurate translation.

exports.default = {
  error: {
    forgotPassword: {
      too_many_requests: 'Ai depășit limita de introducere a parolei. Avem rugămintea să aștepți până la următoarea încercare.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de recuperare a parolei.',
      enterprise_email: 'Domeniul e-mailului dvs. face parte dintr-un furnizor de identitate de tip Enterprise. Pentru a reseta parola, consultați administratorul de securitate.'
    },
    login: {
      blocked_user: 'Utilizatorul este blocat.',
      invalid_user_password: 'Date de conectare greșite.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de conectare.',
      'lock.invalid_code': 'Cod greșit.',
      'lock.invalid_email_password': 'Email sau parolă greșite.',
      'lock.invalid_username_password': 'Nume utilizator sau parolă greșite.',
      'lock.network': 'Nu am putut să ne conectăm la server. Avem rugămintea să verifici conexiunea și să încerci din nou.',
      'lock.popup_closed': 'Fereastra popup a fost închisă. Te rugăm încearcă din nou.',
      'lock.unauthorized': 'Nu ai primit permisiunea să te conectezi. Te rugăm încearcă din nou.',
      'lock.mfa_registration_required': 'Dispozitivul tău nu permite conectarea. Avem rugămintea să verifici setările.',
      'lock.mfa_invalid_code': 'Cod greșit. Te rugăm să încerci din nou',
      password_change_required: 'Trebuie să schimbi parola de acces. Parola a expirat sau este prima oară când te conectezi.',
      password_leaked: 'Am identificat o posibilă problemă de securitate cu acest cont. Am blocat contul pentru a te proteja. Urmează să primești un email cu instrucțiunile de deblocare a contului',
      too_many_attempts: 'Contul tău a fost blocat după mai multe încercări nereușite de conectare.',
      session_missing: 'Nu am putut finaliza procesul de autentificare. Avem rugămintea să încerci după ce închizi toate ferestrele deschise.',
      'hrd.not_matching_email': 'Te rugăm să folosești adresa de email corporate pentru conectare.'
    },
    passwordless: {
      'bad.email': 'Adresa de email este invalidă',
      'bad.phone_number': 'Numărul de telefon este invalid',
      'lock.fallback': 'Ne pare rău, ceva nu a funcționat'
    },
    signUp: {
      invalid_password: 'Parolă invalidă.',
      'lock.fallback': 'Ne pare rău, a apărut o eroare în procesul de înregistrare.',
      password_dictionary_error: 'Parola este prea comună.',
      password_no_user_info_error: 'Parola este similară cu utilizatorul.',
      password_strength_error: 'Parola este prea ușoară.',
      user_exists: 'Utilizator existent.',
      username_exists: 'Nume utilizator existent.'
    }
  },
  success: {
    logIn: 'Îți mulțumim pentru înregistrare.',
    forgotPassword: 'Ți-am transmis un email pentru resetarea parolei.',
    magicLink: 'Ți-am trimis un email pentru a te înregistra<br />la %s.',
    signUp: 'Îți mulțumim pentru înregistrare.'
  },
  blankErrorHint: 'Câmpul nu poate fi gol',
  codeInputPlaceholder: 'codul tău',
  databaseEnterpriseLoginInstructions: '',
  databaseEnterpriseAlternativeLoginInstructions: 'sau',
  databaseSignUpInstructions: '',
  databaseAlternativeSignUpInstructions: 'sau',
  emailInputPlaceholder: 'yours@example.com',
  enterpriseLoginIntructions: 'Înregistrează-te cu datele corporate.',
  enterpriseActiveLoginInstructions: ' Înregistrează-te cu datele corporate la %s.',
  failedLabel: 'Eșuat!',
  forgotPasswordTitle: 'Resetează parola',
  forgotPasswordAction: 'Nu îți amintești parola?',
  forgotPasswordInstructions: 'Avem rugămintea să introduci adresa de email. Urmează să primești un email pentru resetarea parolei.',
  forgotPasswordSubmitLabel: 'Email transmis',
  invalidErrorHint: 'Invalid',
  lastLoginInstructions: 'Ultima oară când te-ai conectat',
  loginAtLabel: ' Autentifică-te cu %s',
  loginLabel: 'Autentifică-te',
  loginSubmitLabel: 'Autentifică-te',
  loginWithLabel: ' Autentifică-te cu %s',
  notYourAccountAction: 'Nu este contul tău?',
  passwordInputPlaceholder: 'parola ta',
  passwordStrength: {
    containsAtLeast: 'Include cel puțin %d din urmatoarele %d caractere:',
    identicalChars: 'Nu mai mult de %d caractere identice (e.x., "%s" nu sunt permise)',
    nonEmpty: 'Este necesară o parolă pentru logare',
    numbers: 'Numere (de la 0-9)',
    lengthAtLeast: 'Cel puțin %d caractere lungime',
    lowerCase: 'Litere mici (a-z)',
    shouldContain: 'Trebuie să conțină:',
    specialCharacters: 'Caractere speciale (e.g. !@#$%^&*)',
    upperCase: 'Litere cu majuscule (A-Z)'
  },
  passwordlessEmailAlternativeInstructions: 'Dacă nu, introdu adresa de email pentru conectare<br/>sau creează un cont.',
  passwordlessEmailCodeInstructions: 'Un email cu codul a fost trimis la %s.',
  passwordlessEmailInstructions: 'Introdu adresa de email pentru conectare<br/>sau creează un cont',
  passwordlessSMSAlternativeInstructions: ' Dacă nu, introdu un număr de telefon pentru conectare <br/>sau creează un cont',
  passwordlessSMSCodeInstructions: 'Un SMS cu codul de acces a fost trimis la<br/>la %s.',
  passwordlessSMSInstructions: 'Introdu numărul de telefon pentru conectare<br/>sau creează un cont',
  phoneNumberInputPlaceholder: 'numărul tău de telefon',
  resendCodeAction: 'Nu ai primit codul de acces? ',
  resendLabel: 'Retrimite',
  resendingLabel: 'Se retrimite...',
  retryLabel: 'Reîncearcă',
  sentLabel: 'Transmis!',
  showPassword: 'Arată parola',
  signUpTitle: 'Inregistrează-te',
  signUpLabel: ' Inregistrează-te ',
  signUpSubmitLabel: ' Inregistrează-te ',
  signUpWithLabel: ' Inregistrează-te cu %s',
  socialLoginInstructions: '',
  socialSignUpInstructions: '',
  ssoEnabled: ' Inregistrare activată',
  submitLabel: 'Trimite',
  unrecoverableError: 'Ceva nu a mers.<br />Avem rugămintea să contactezi serviciul de suport tehnic.',
  usernameFormatErrorHint: 'Folosește %d-%d litere, cifre și următoarele caractere speciale: "_", ".", "+", "-"',
  usernameInputPlaceholder: 'numele tău de utilizator',
  usernameOrEmailInputPlaceholder: 'utilizator/email',
  title: 'Auth0',
  welcome: 'Bine ai venit %s!',
  windowsAuthInstructions: 'Ești conectat de pe serverul tău corporate',
  windowsAuthLabel: 'Autentificare Windows ',
  mfaInputPlaceholder: 'Cod',
  mfaLoginTitle: 'Verificare în doi pași',
  mfaLoginInstructions: 'Te rugăm să introduci codul de autentificare generat de aplicația mobilă.',
  mfaSubmitLabel: 'Conectare',
  mfaCodeErrorHint: 'Utilizează %d cifre',
  signUpTerms: 'Prin înscrierea dvs. sunteți de acord cu termenii și condițiile noastre de utilizare și de politică de confidențialitate.'
};
